==> haskell-tls-session-manager-0.0.6-12-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tls-session-manager
version:              0.0.6
visibility:           public
id:                   tls-session-manager-0.0.6-H1eqJvq9mCy9YghTvTS0GV
key:                  tls-session-manager-0.0.6-H1eqJvq9mCy9YghTvTS0GV
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             In-memory TLS session DB and session ticket
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance and session ticket manager

category:             Web
abi:                  bfa833bcf9a235ea9e35877446d7741a
exposed:              True
exposed-modules:      Network.TLS.SessionManager Network.TLS.SessionTicket
hidden-modules:       Network.TLS.Imports
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tls-session-manager-0.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tls-session-manager-0.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tls-session-manager-0.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tls-session-manager
hs-libraries:         HStls-session-manager-0.0.6-H1eqJvq9mCy9YghTvTS0GV
depends:
    auto-update-0.1.6-9ryA5SLAC8xHZnIgVWhrWD base-4.18.2.1
    basement-0.0.16-HvTgG10TboKKpCgs2TlMDx bytestring-0.11.5.3
    clock-0.8.4-DWXp61AeHFIv4cYLkfaEg
    crypto-token-0.1.2-IQscVG2wpVu806DTaWJZS
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    psqueues-0.2.8.2-7Hsdb7lcqdu8EEvCE8H06F
    serialise-0.2.6.1-H8jGFFiph3l4AopTRNckmn
    tls-2.0.6-HHKVvNcSfLyJGme2UrIiax

haddock-interfaces:
    /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock

haddock-html:         /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-session-manager-0.0.6-13-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tls-session-manager
version:              0.0.6
visibility:           public
id:                   tls-session-manager-0.0.6-IToj1vuJmt6HbDWjOxqNUV
key:                  tls-session-manager-0.0.6-IToj1vuJmt6HbDWjOxqNUV
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             In-memory TLS session DB and session ticket
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance and session ticket manager

category:             Web
abi:                  25508d844ee320b7f0909098050489a6
exposed:              True
exposed-modules:      Network.TLS.SessionManager Network.TLS.SessionTicket
hidden-modules:       Network.TLS.Imports
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tls-session-manager-0.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tls-session-manager-0.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tls-session-manager-0.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tls-session-manager
hs-libraries:         HStls-session-manager-0.0.6-IToj1vuJmt6HbDWjOxqNUV
depends:
    auto-update-0.1.6-88T3ReDBoup7kx6uceSFG6 base-4.18.2.1
    basement-0.0.16-HvTgG10TboKKpCgs2TlMDx bytestring-0.11.5.3
    clock-0.8.4-IMsJrS0UrDMF6MHHHvKozA
    crypto-token-0.1.2-2d88nFd0vTmHgdc2NliHLH
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    psqueues-0.2.8.2-8uu3DxPW2eP1IKqIpq0lUH
    serialise-0.2.6.1-1dianXJhkpM97MZAKPCh4L
    tls-2.0.6-CMnie4Wyps5DmePV9nSMbU

haddock-interfaces:
    /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock

haddock-html:         /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
